pub enum AutoMigratePrecheck<'def> {
CheckAddSequenceRangeValid(<SequenceDef as ModuleDefLookup>::Key<'def>),
}Expand description
Checks that must be performed before performing an automatic migration. These checks can access table contents and other database state.
Variants
CheckAddSequenceRangeValid(<SequenceDef as ModuleDefLookup>::Key<'def>)
Perform a check that adding a sequence is valid (the relevant column contains no values greater than the sequence’s start value).