#[non_exhaustive]pub struct ColumnDef {
pub name: Identifier,
pub accessor_name: Identifier,
pub col_id: ColId,
pub ty: AlgebraicType,
pub ty_for_generate: AlgebraicTypeUse,
pub table_name: Identifier,
pub default_value: Option<AlgebraicValue>,
}Expand description
A struct representing the validated definition of a database column.
Cannot be created directly. Construct a ModuleDef by validating a RawModuleDef instead,
and then access the column from there.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: IdentifierThe name of the column.
Unique within the containing TableDef, but
NOT within the containing ModuleDef.
accessor_name: IdentifierThe name of the column as define in the module source code.
This should be used in client codegens and Not name field.
col_id: ColIdThe ID of this column.
ty: AlgebraicTypeThe type of this column. May refer to the containing ModuleDef’s Typespace.
Must satisfy AlgebraicType::is_valid_for_client_type_use.
Will always correspond to the corresponding element of this table’s
product_type_ref, that is, the element at index col_id.idx()
with name Some(name.as_str()).
ty_for_generate: AlgebraicTypeUseThe type of the column, formatted for client code generation.
table_name: IdentifierThe table this ColumnDef is stored in.
default_value: Option<AlgebraicValue>The default value of this column, if present.