#[non_exhaustive]pub struct ProcedureDef {
pub name: Identifier,
pub accessor_name: Identifier,
pub params: ProductType,
pub params_for_generate: ProductTypeDef,
pub return_type: AlgebraicType,
pub return_type_for_generate: AlgebraicTypeUse,
pub visibility: FunctionVisibility,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: IdentifierThe name of the procedure.
This must be unique within the module’s set of reducers and procedures.
accessor_name: IdentifierThe procedure name as defined in the module source.
Similar to [ReducerDef.accessor_name].
params: ProductTypeThe parameters of the procedure.
This ProductType need not be registered in the module’s Typespace.
params_for_generate: ProductTypeDefThe parameters of the procedure, formatted for client codegen.
This ProductType need not be registered in the module’s TypespaceForGenerate.
return_type: AlgebraicTypeThe return type of the procedure.
If this is a non-special compound type, it should be registered in the module’s Typespace
and indirected through an AlgebraicType::Ref.
return_type_for_generate: AlgebraicTypeUseThe return type of the procedure.
If this is a non-special compound type, it should be registered in the module’s TypespaceForGenerate
and indirected through an AlgebraicTypeUse::Ref.
visibility: FunctionVisibilityThe visibility of this procedure.