#[non_exhaustive]pub struct ReducerDef {
pub name: ReducerName,
pub accessor_name: ReducerName,
pub params: ProductType,
pub params_for_generate: ProductTypeDef,
pub lifecycle: Option<Lifecycle>,
pub visibility: FunctionVisibility,
pub ok_return_type: AlgebraicType,
pub err_return_type: AlgebraicType,
}Expand description
A reducer exported by the module.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: ReducerNameThe name of the reducer. This must be unique within the module’s set of reducers and procedures.
accessor_name: ReducerNameThe reducer name as defined in the module source.
All the codegens should use accessor_name to generate reducers.
However, the name field should still be used when communicating with the
database over the network, since the database does not necessarily know
about accessor names.
params: ProductTypeThe parameters of the reducer.
This ProductType need not be registered in the module’s Typespace.
params_for_generate: ProductTypeDefThe parameters of the reducer, formatted for client codegen.
This ProductType need not be registered in the module’s TypespaceForGenerate.
lifecycle: Option<Lifecycle>The special role of this reducer in the module lifecycle, if any.
visibility: FunctionVisibilityThe visibility of this reducer.
ok_return_type: AlgebraicTypeThe return type of the reducer on success.
err_return_type: AlgebraicTypeThe return type of the reducer on error.