ViewDef

Struct ViewDef 

#[non_exhaustive]
pub struct ViewDef {
Show 13 fields pub name: Identifier, pub accessor_name: Identifier, pub is_public: bool, pub is_anonymous: bool, pub fn_ptr: ViewFnPtr, pub params: ProductType, pub params_for_generate: ProductTypeDef, pub return_type: AlgebraicType, pub return_type_for_generate: AlgebraicTypeUse, pub product_type_ref: AlgebraicTypeRef, pub primary_key: Option<ColId>, pub return_columns: Vec<ViewColumnDef>, pub param_columns: Vec<ViewParamDef>,
}
A view exported by the module.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Identifier

The name of the view. This must be unique within the module.

accessor_name: Identifier

The view identifier as defined in the module source.

Similar to [TableDef.accessor_name].

is_public: bool

Is this a public or a private view? Currently only public views are supported. Private views may be supported in the future.

is_anonymous: bool

Is this view anonymous? An anonymous view does not know who called it. Specifically, it is a view that has an AnonymousViewContext as its first argument. This type does not have access to the Identity of the caller.

fn_ptr: ViewFnPtr

It represents the unique index of this view within the module. Module contains separate list for anonymous and non-anonymous views, so is_anonymous is needed to fully identify the view along with this index.

params: ProductType

The parameters of the view.

This ProductType need not be registered in the module’s Typespace.

params_for_generate: ProductTypeDef

The parameters of the view, formatted for client codegen.

This ProductType need not be registered in the module’s TypespaceForGenerate.

return_type: AlgebraicType

The return type of the view. Either Option<T>, Vec<T>, or Query<T> where:

  1. T is a ProductType containing the columns of the view
  2. T is registered in the module’s typespace
  3. Option<T> refers to AlgebraicType::option()
  4. Vec<T> refers to AlgebraicType::array()
  5. Query<T> is a special ProductType { __query__: T }
return_type_for_generate: AlgebraicTypeUse

The return type of the view, formatted for client codegen.

product_type_ref: AlgebraicTypeRef

The single source of truth for the view’s columns.

If a view can return only Option<T>, Vec<T>, or Query<T>, this is a reference to the inner product type T. All elements of T must have names.

primary_key: Option<ColId>

The primary key of the view.

This is set for query-builder views when the underlying table has a primary key. The database engine does not actually care about this, but client code generation does.

return_columns: Vec<ViewColumnDef>

The return columns of this view. The same information is stored in product_type_ref. This is just a more convenient-to-access format.

param_columns: Vec<ViewParamDef>

The columns that track the arguments of this view. The same information is stored in params. This is just a more convenient-to-access format.

Implementations

Source

impl ViewDef

pub fn get_column_by_name(&self, name: &Identifier) -> Option<&ViewColumnDef>

Get a column by the column’s name.

pub fn get_param_by_name(&self, name: &Identifier) -> Option<&ViewParamDef>

Get a parameter by the parameter’s name.