pub type IdentifierMap<T> = HashMap<Identifier, T>;Expand description
A map from Identifiers to values of type T.
Aliased Type
pub struct IdentifierMap<T> { /* private fields */ }pub type IdentifierMap<T> = HashMap<Identifier, T>;A map from Identifiers to values of type T.
pub struct IdentifierMap<T> { /* private fields */ }