TableOrViewSchema

Struct TableOrViewSchema 

pub struct TableOrViewSchema {
    pub table_id: TableId,
    pub view_info: Option<ViewDefInfo>,
    pub table_name: TableName,
    pub table_access: StAccess,
    /* private fields */
}
A wrapper around a TableSchema for views.

Fields

table_id: TableIdview_info: Option<ViewDefInfo>table_name: TableNametable_access: StAccess

Implementations

Source

impl TableOrViewSchema

pub fn is_view(&self) -> bool

Is this schema that of a view?

pub fn is_anonymous_view(&self) -> bool

Is this schema that of an anonymous view?

pub fn inner(&self) -> Arc<TableSchema>

Returns the TableSchema of the underlying datastore table. For views, this schema will include the internal sender and arg_id columns.

pub fn public_columns(&self) -> &[ColumnSchema]

Returns the public columns of this table.

The ColIds in this list do not necessarily correspond to their position in this list. Rather they correspond to the position of the column in the physical datastore table. This is important since this method may not return all columns recorded in the datastore. For views in particular it will not include the internal sender and arg_id columns. Hence columns in this list should be looked up by their ColId - not their position.

pub fn get_column_by_name(&self, col_name: &str) -> Option<&ColumnSchema>

Check if the col_name exist on this TableOrViewSchema

pub fn get_column_by_name_or_alias( &self, col_name: &str, ) -> Option<&ColumnSchema>

Check if the col_name exists on this TableOrViewSchema, prioritizing alias over canonical name.